==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Engines/mplayer/translations/mplayer_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>MplayerEngineFactory</name>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="34"/>
        <source>Mplayer Plugin</source>
        <translation>Mplayer プラグイン</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="37"/>
        <source>Video Files</source>
        <translation>ビデオファイル</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="84"/>
        <source>About MPlayer Plugin</source>
        <translation>MPlayer プラグインについて</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="85"/>
        <source>Qmmp MPlayer Plugin</source>
        <translation>QMMP MPlayer プラグイン</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="86"/>
        <source>This plugin uses MPlayer as backend</source>
        <translation>このプラグインの実行は MPlayer で裏打ちされています</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="87"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MplayerMetaDataModel</name>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="39"/>
        <source>Size</source>
        <translation>大きさ</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="39"/>
        <source>KiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="65"/>
        <source>Demuxer</source>
        <translation>デマルチプレクサー</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="67"/>
        <source>Video format</source>
        <translation>映像の形式</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="68"/>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="69"/>
        <source>Video codec</source>
        <translation>映像の符号形式</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="70"/>
        <source>Aspect ratio</source>
        <translation>縦横比</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="71"/>
        <source>Video bitrate</source>
        <translation>映像のビットレート</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="71"/>
        <location filename="../mplayermetadatamodel.cpp" line="76"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="74"/>
        <source>Audio codec</source>
        <translation>音響の符号形式</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="75"/>
        <source>Sample rate</source>
        <translation>サンプルレート</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="75"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="76"/>
        <source>Audio bitrate</source>
        <translation>音響のビットレート</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="77"/>
        <source>Channels</source>
        <translation>チャンネル</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="72"/>
        <source>Resolution</source>
        <translation>解像度</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPlayer Settings</source>
        <translation>MPlayer 設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Video:</source>
        <translation>映像:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Audio:</source>
        <translation>音響:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Audio/video auto synchronization</source>
        <translation>音響と映像の自動同期</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <source>Synchronization factor:</source>
        <translation>同期因子:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>Extra options:</source>
        <translation>追加オプション:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>Extra command line options</source>
        <translation>コマンド行で追加するオプション</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="29"/>
        <location filename="../settingsdialog.cpp" line="37"/>
        <location filename="../settingsdialog.cpp" line="46"/>
        <location filename="../settingsdialog.cpp" line="47"/>
        <location filename="../settingsdialog.cpp" line="61"/>
        <location filename="../settingsdialog.cpp" line="62"/>
        <source>default</source>
        <translation>初期設定値</translation>
    </message>
</context>
</TS>

==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/Engines/mplayer/translations/mplayer_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>MplayerEngineFactory</name>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="34"/>
        <source>Mplayer Plugin</source>
        <translation>Mplayer プラグイン</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="37"/>
        <source>Video Files</source>
        <translation>ビデオファイル</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="83"/>
        <source>About MPlayer Plugin</source>
        <translation>MPlayer プラグインについて</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="84"/>
        <source>Qmmp MPlayer Plugin</source>
        <translation>QMMP MPlayer プラグイン</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="85"/>
        <source>This plugin uses MPlayer as backend</source>
        <translation>このプラグインの実行は MPlayer で裏打ちされています</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="86"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MplayerMetaDataModel</name>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="38"/>
        <source>Size</source>
        <translation>大きさ</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="38"/>
        <source>KB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="75"/>
        <source>Length</source>
        <translation>長さ</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="77"/>
        <source>Demuxer</source>
        <translation>デマルチプレクサー</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="80"/>
        <source>Video format</source>
        <translation>映像の形式</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="82"/>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="84"/>
        <source>Video codec</source>
        <translation>映像の符号形式</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="86"/>
        <source>Aspect ratio</source>
        <translation>縦横比</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="88"/>
        <source>Video bitrate</source>
        <translation>映像のビットレート</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="95"/>
        <source>Audio codec</source>
        <translation>音響の符号形式</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="97"/>
        <source>Sample rate</source>
        <translation>サンプルレート</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="99"/>
        <source>Audio bitrate</source>
        <translation>音響のビットレート</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="101"/>
        <source>Channels</source>
        <translation>チャンネル</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="103"/>
        <source>Resolution</source>
        <translation>解像度</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPlayer Settings</source>
        <translation>MPlayer 設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Video:</source>
        <translation>映像:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Audio:</source>
        <translation>音響:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Audio/video auto synchronization</source>
        <translation>音響と映像の自動同期</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <source>Synchronization factor:</source>
        <translation>同期因子:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>Extra options:</source>
        <translation>追加オプション:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>Extra command line options</source>
        <translation>コマンド行で追加するオプション</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="29"/>
        <location filename="../settingsdialog.cpp" line="37"/>
        <location filename="../settingsdialog.cpp" line="46"/>
        <location filename="../settingsdialog.cpp" line="47"/>
        <location filename="../settingsdialog.cpp" line="61"/>
        <location filename="../settingsdialog.cpp" line="62"/>
        <source>default</source>
        <translation>初期設定値</translation>
    </message>
</context>
</TS>
